@@ -47,7 +47,6 @@ class quotas extends Survey_Common_Action
     {
         // Set the variables in an array
         $aData['iSurveyId'] = $aData['surveyid'] = $iSurveyId;
-        $aData['clang'] = $this->getController()->lang;
         $aData['sBaseLang'] = Survey::model()->findByPk($iSurveyId)->language;
         $aData['aLangs'] = Survey::model()->findByPk($iSurveyId)->additionalLanguages;
         array_unshift($aData['aLangs'], $aData['sBaseLang']);
@@ -61,23 +60,21 @@ class quotas extends Survey_Common_Action
 
     private function _checkPermissions($iSurveyId, $sPermission)
     {
-        $clang=$this->getController()->lang;
         if (!empty($sPermission) && !(Permission::model()->hasSurveyPermission($iSurveyId, 'quotas', $sPermission))) {
-            Yii::app()->session['flashmessage'] = $clang->gT('Access denied!');
+            Yii::app()->session['flashmessage'] =gT('Access denied!');
             $this->_redirectToIndex($iSurveyId);
         }
     }
 
     function _redirectToIndex($iSurveyId)
     {
-        $clang=$this->getController()->lang;
         if(Permission::model()->hasSurveyPermission($iSurveyId, 'quotas','read'))
         {
             $this->getController()->redirect($this->getController()->createUrl("/admin/quotas/sa/index/surveyid/$iSurveyId"));
         }
         else
         {
-            Yii::app()->session['flashmessage'] = $clang->gT('Access denied!');
+            Yii::app()->session['flashmessage'] =gT('Access denied!');
             $this->getController()->redirect($this->getController()->createUrl("admin/survey/sa/view/surveyid/$iSurveyId"));
         }
     }
@@ -94,7 +91,19 @@ class quotas extends Survey_Common_Action
             $aViewUrls[] = 'viewquotas_view';
         }
 
-        $clang = $aData['clang'];
+        $aData['surveyid'] = $iSurveyID = $surveyid =  sanitize_int($iSurveyId);
+
+        $aData['sidemenu']['state'] = false;
+        $surveyinfo = Survey::model()->findByPk($iSurveyID)->surveyinfo;
+        $aData['title_bar']['title'] = $surveyinfo['surveyls_title']."(".gT("ID").":".$iSurveyID.")";
+
+        //$aData['surveybar']['active_survey_properties'] = 'quotas';
+        $aData['surveybar']['buttons']['view']= TRUE;
+        $aData['surveybar']['active_survey_properties']['img'] = 'quota';
+        $aData['surveybar']['active_survey_properties']['txt'] = gT("Quotas");
+        $aData['surveybar']['closebutton']['url'] = 'admin/survey/sa/view/surveyid/'.$iSurveyID;  // Close button
+        $aData['surveybar']['closebutton']['forbidden'][] = 'quotas';
+
         $totalquotas = 0;
         $totalcompleted = 0;
         $csvoutput = array();
@@ -108,9 +117,11 @@ class quotas extends Survey_Common_Action
         $aResult = Quota::model()->findAll($criteria);
 
         //if there are quotas let's proceed
+        $aViewUrls['output'] = '';
         if (count($aResult) > 0)
         {
-            $aViewUrls['output'] = '';
+            $aData['output'] = '';
+
             //loop through all quotas
             foreach ($aResult as $aQuotaListing)
             {
@@ -130,7 +141,26 @@ class quotas extends Survey_Common_Action
                 $aData['completed'] = $completed;
                 $aData['totalquotas'] = $totalquotas;
                 $aData['totalcompleted'] = $totalcompleted;
+
+                // Edit URL
+                $aData['editUrl'] = App()->createUrl("admin/quotas/sa/editquota/surveyid/" . $iSurveyId, array(
+                    'sid' => $iSurveyId,
+                    'action' => 'quotas',
+                    'quota_id' => $aQuotaListing['id'],
+                    'subaction' => 'quota_editquota'
+
+                ));
+
+                // Delete URL
+                $aData['deleteUrl'] = App()->createUrl("admin/quotas/sa/delquota/surveyid/" . $iSurveyId, array(
+                    'sid' => $iSurveyId,
+                    'action' => 'quotas',
+                    'quota_id' => $aQuotaListing['id'],
+                    'subaction' => 'quota_delquota'
+                ));
+
                 $aViewUrls['output'] .= $this->getController()->renderPartial("/admin/quotas/viewquotasrow_view", $aData, true);
+                $aData['output'] .= $this->getController()->renderPartial("/admin/quotas/viewquotasrow_view", $aData, true);
 
                 //check how many sub-elements exist for a certain quota
                 $aResults2 = QuotaMember::model()->findAllByAttributes(array('quota_id' => $aQuotaListing['id']));
@@ -142,13 +172,16 @@ class quotas extends Survey_Common_Action
                     $aData['question_answers'] = $aQuestionAnswers;
                     $aData['quota_questions'] = $aQuotaQuestions;
                     $aViewUrls['output'] .= $this->getController()->renderPartial('/admin/quotas/viewquotasrowsub_view', $aData, true);
+                    //$aData['output'] .= $this->getController()->renderPartial('/admin/quotas/viewquotasrowsub_view', $aData, true);
                 }
+
             }
         }
         else
         {
             // No quotas have been set for this survey
-            $aViewUrls[] = 'viewquotasempty_view';
+            //$aViewUrls[] = 'viewquotasempty_view';
+            $aData['output'] = $this->getController()->renderPartial('/admin/quotas/viewquotasempty_view', $aData, true);
         }
 
         $aData['totalquotas'] = $totalquotas;
@@ -156,15 +189,19 @@ class quotas extends Survey_Common_Action
 
         if ($quickreport == false)
         {
-            $aViewUrls[] = 'viewquotasfooter_view';
+            //$aViewUrls[] = 'viewquotasfooter_view';
+            $aViewUrls['output'] .= $this->getController()->renderPartial('/admin/quotas/viewquotasfooter_view', $aData, true);
             $this->_renderWrappedTemplate('quotas', $aViewUrls, $aData);
         }
         else
         {
+
+            //// WHY ???????
+
             header("Content-Disposition: attachment; filename=results-survey" . $iSurveyId . ".csv");
             header("Content-type: text/comma-separated-values; charset=UTF-8");
             header("Pragma: public");
-            echo $clang->gT("Quota name") . "," . $clang->gT("Limit") . "," . $clang->gT("Completed") . "," . $clang->gT("Remaining") . "\r\n";
+            echo gT("Quota name") . "," . gT("Limit") . "," . gT("Completed") . "," . gT("Remaining") . "\r\n";
             foreach ($csvoutput as $line)
             {
                 echo $line;
@@ -186,6 +223,7 @@ class quotas extends Survey_Common_Action
         $oQuota->qlimit = Yii::app()->request->getPost('quota_limit');
         $oQuota->action = Yii::app()->request->getPost('quota_action');
         $oQuota->autoload_url = Yii::app()->request->getPost('autoload_url');
+        $oQuota->active = Yii::app()->request->getPost('active');
         $oQuota->save();
         $iQuotaId = $oQuota->id;
 
@@ -223,6 +261,7 @@ class quotas extends Survey_Common_Action
                 $oQuotaLanguageSettings->quotals_urldescrip = $_POST['quotals_urldescrip_' . $sLang];
                 $oQuotaLanguageSettings->save();
             }
+            Yii::app()->user->setFlash('success', gT("New quota saved"));
         }
 
         self::_redirectToIndex($iSurveyId);
@@ -240,6 +279,7 @@ class quotas extends Survey_Common_Action
         $oQuota->qlimit = Yii::app()->request->getPost('quota_limit');
         $oQuota->action = Yii::app()->request->getPost('quota_action');
         $oQuota->autoload_url = Yii::app()->request->getPost('autoload_url');
+        $oQuota->active = Yii::app()->request->getPost('active');
         $oQuota->save();
 
         //Iterate through each language posted, and make sure there is a quota message for it
@@ -329,9 +369,13 @@ class quotas extends Survey_Common_Action
         $iSurveyId = sanitize_int($iSurveyId);
         $this->_checkPermissions($iSurveyId, 'delete');
 
-        Quota::model()->deleteByPk(Yii::app()->request->getPost('quota_id'));
-        QuotaLanguageSetting::model()->deleteAllByAttributes(array('quotals_quota_id' => Yii::app()->request->getPost('quota_id')));
-        QuotaMember::model()->deleteAllByAttributes(array('quota_id' => Yii::app()->request->getPost('quota_id')));
+        $quotaId = Yii::app()->request->getQuery('quota_id');
+
+        Quota::model()->deleteByPk($quotaId);
+        QuotaLanguageSetting::model()->deleteAllByAttributes(array('quotals_quota_id' => $quotaId));
+        QuotaMember::model()->deleteAllByAttributes(array('quota_id' => $quotaId));
+
+        Yii::app()->user->setFlash('success', sprintf(gT("Quota with ID %s was deleted"), $quotaId));
 
         self::_redirectToIndex($iSurveyId);
     }
@@ -342,10 +386,10 @@ class quotas extends Survey_Common_Action
         $this->_checkPermissions($iSurveyId, 'update');
         $aData = $this->_getData($iSurveyId);
         $aLangs = $aData['aLangs'];
-        $clang = $aData['clang'];
         $aViewUrls = array();
+        $quotaId = Yii::app()->request->getQuery('quota_id');
 
-        $aQuotaInfo = Quota::model()->findByPk(Yii::app()->request->getPost('quota_id'));
+        $aQuotaInfo = Quota::model()->findByPk($quotaId);
         $aData['quotainfo'] = $aQuotaInfo;
 
         $first=true;
@@ -354,10 +398,10 @@ class quotas extends Survey_Common_Action
             $aTabTitles[$sLanguage] = getLanguageNameFromCode($sLanguage, false);
             if ($first)
             {
-                $aTabTitles[$sLanguage].= ' (' . $clang->gT("Base language") . ')';
+                $aTabTitles[$sLanguage].= ' (' . gT("Base language") . ')';
                 $first = false;
             }
-            $aData['langquotainfo'] = QuotaLanguageSetting::model()->findByAttributes(array('quotals_quota_id' => Yii::app()->request->getPost('quota_id'), 'quotals_language' => $sLanguage));
+            $aData['langquotainfo'] = QuotaLanguageSetting::model()->findByAttributes(array('quotals_quota_id' => $quotaId, 'quotals_language' => $sLanguage));
             $aData['lang'] = $sLanguage;
             $aTabContents[$sLanguage] = $this->getController()->renderPartial('/admin/quotas/editquotalang_view', $aData, true);
         }
@@ -366,16 +410,29 @@ class quotas extends Survey_Common_Action
 
         $aViewUrls[] = 'editquota_view';
 
+        $aData['sidemenu']['state'] = false;
+        $surveyinfo = Survey::model()->findByPk($iSurveyId)->surveyinfo;
+        $aData['title_bar']['title'] = $surveyinfo['surveyls_title']."(".gT("ID").":".$iSurveyId.")";
+
+        //$aData['surveybar']['active_survey_properties'] = 'quotas';
+        $aData['surveybar']['closebutton']['url'] = 'admin/quotas/sa/index/surveyid/'.$iSurveyId;  // Close button
+        $aData['surveybar']['savebutton']['form'] = 'frmeditgroup';
+
+        $aData['langs'] = $aData['aLangs'];
+        $aData['baselang'] = $aData['sBaseLang'];
+
         $this->_renderWrappedTemplate('quotas', $aViewUrls, $aData);
     }
 
+    /**
+     * Add new answer to quota
+     */
     function new_answer($iSurveyId, $sSubAction = 'new_answer')
     {
         $iSurveyId = sanitize_int($iSurveyId);
         $this->_checkPermissions($iSurveyId, 'update');
         $aData = $this->_getData($iSurveyId);
         $sBaseLang = $aData['sBaseLang'];
-        $clang = $aData['clang'];
         $aViewUrls = array();
 
         if (($sSubAction == "new_answer" || ($sSubAction == "new_answer_two" && !isset($_POST['quota_qid']))) && Permission::model()->hasSurveyPermission($iSurveyId, 'quotas', 'create'))
@@ -420,6 +477,12 @@ class quotas extends Survey_Common_Action
             $aViewUrls[] = 'newanswertwo_view';
         }
 
+        $aData['sidemenu']['state'] = false;
+        $surveyinfo = Survey::model()->findByPk($iSurveyId)->surveyinfo;
+        $aData['title_bar']['title'] = $surveyinfo['surveyls_title']."(".gT("ID").":".$iSurveyId.")";
+        $aData['surveybar']['closebutton']['url'] = 'admin/quotas/sa/index/surveyid/'.$iSurveyId;  // Close button
+        $aData['surveybar']['closebutton']['forbidden'][] = 'new_answer';
+
         $this->_renderWrappedTemplate('quotas', $aViewUrls, $aData);
     }
 
@@ -428,17 +491,22 @@ class quotas extends Survey_Common_Action
         $iSurveyId = sanitize_int($iSurveyId);
         $this->_checkPermissions($iSurveyId, 'create');
         $aData = $this->_getData($iSurveyId);
-        $clang = $aData['clang'];
 
         $aData['thissurvey'] = getSurveyInfo($iSurveyId);
         $aData['langs'] = $aData['aLangs'];
         $aData['baselang'] = $aData['sBaseLang'];
 
+        $aData['sidemenu']['state'] = false;
+        $surveyinfo = Survey::model()->findByPk($iSurveyId)->surveyinfo;
+        $aData['title_bar']['title'] = $surveyinfo['surveyls_title']."(".gT("ID").":".$iSurveyId.")";
+        $aData['surveybar']['savebutton']['form'] = 'frmeditgroup';
+        $aData['surveybar']['closebutton']['url'] = 'admin/quotas/sa/index/surveyid/'.$iSurveyId;  // Close button
+
         $this->_renderWrappedTemplate('quotas', 'newquota_view', $aData);
     }
 
     /**
-     * 
+     *
      * @param type $iQuestionId
      * @param type $iSurveyId
      * @param type $iQuotaId
@@ -451,8 +519,9 @@ class quotas extends Survey_Common_Action
         $iQuotaId    = sanitize_int($iQuotaId);
         $aData       = $this->_getData($iSurveyId);
         $sBaseLang   = $aData['sBaseLang'];
-        $clang       = $aData['clang'];
         $this->_checkPermissions($iSurveyId, 'read');
+
+
         $aQuestion = Question::model()->findByPk(array('qid' => $iQuestionId, 'language' => $sBaseLang));
         $aQuestionType = $aQuestion['type'];
 
@@ -469,18 +538,20 @@ class quotas extends Survey_Common_Action
         } elseif ($aQuestionType == 'G')
         {
             $aAnswerList = array(
-                'M' => array('Title' => $aQuestion['title'], 'Display' => $clang->gT("Male"), 'code' => 'M'),
-                'F' => array('Title' => $aQuestion['title'], 'Display' => $clang->gT("Female"), 'code' => 'F'));
+                'M' => array('Title' => $aQuestion['title'], 'Display' => gT("Male"), 'code' => 'M'),
+                'F' => array('Title' => $aQuestion['title'], 'Display' => gT("Female"), 'code' => 'F'));
         } elseif ($aQuestionType == 'L' || $aQuestionType == 'O' || $aQuestionType == '!')
         {
-            $aAnsResults = Answer::model()->findAllByAttributes(array('qid' => $iQuestionId));
+
+            $aAnsResults = Answer::model()->findAllByAttributes(array('qid' => $iQuestionId, 'language' => $sBaseLang));
 
             $aAnswerList = array();
 
-            foreach ($aAnsResults as $aDbAnsList) 
+            foreach ($aAnsResults as $aDbAnsList)
             {
                 $aAnswerList[$aDbAnsList['code']] = array('Title' => $aQuestion['title'], 'Display' => substr($aDbAnsList['answer'], 0, 40), 'code' => $aDbAnsList['code']);
             }
+
         } elseif ($aQuestionType == 'A')
         {
             $aAnsResults = Question::model()->findAllByAttributes(array('parent_qid' => $iQuestionId));
@@ -497,7 +568,7 @@ class quotas extends Survey_Common_Action
             }
         } elseif ($aQuestionType == 'B')
         {
-            $aAnsResults = Answer::model()->findAllByAttributes(array('qid' => $iQuestionId));
+            $aAnsResults = Answer::model()->findAllByAttributes(array('qid' => $iQuestionId, 'language' => $sBaseLang));
 
             $aAnswerList = array();
 
@@ -512,8 +583,8 @@ class quotas extends Survey_Common_Action
         } elseif ($aQuestionType == 'Y')
         {
             $aAnswerList = array(
-                'Y' => array('Title' => $aQuestion['title'], 'Display' => $clang->gT("Yes"), 'code' => 'Y'),
-                'N' => array('Title' => $aQuestion['title'], 'Display' => $clang->gT("No"), 'code' => 'N'));
+                'Y' => array('Title' => $aQuestion['title'], 'Display' => gT("Yes"), 'code' => 'Y'),
+                'N' => array('Title' => $aQuestion['title'], 'Display' => gT("No"), 'code' => 'N'));
         } elseif ($aQuestionType == 'I')
         {
             $slangs = Survey::model()->findByPk($iSurveyId)->additionalLanguages;
@@ -529,7 +600,7 @@ class quotas extends Survey_Common_Action
         if (empty($aAnswerList))
         {
             return array();
-        } 
+        }
         else
         {
             // Now we mark answers already used in this quota as such
@@ -554,8 +625,7 @@ class quotas extends Survey_Common_Action
      */
     protected function _renderWrappedTemplate($sAction = 'quotas', $aViewUrls = array(), $aData = array())
     {
-        App()->getClientScript()->registerPackage('jquery-superfish');
-        App()->getClientScript()->registerScriptFile(Yii::app()->getConfig('adminscripts') . '/quotas.js');
+        $this->registerScriptFile( 'ADMIN_SCRIPT_PATH', 'quotas.js');
         parent::_renderWrappedTemplate($sAction, $aViewUrls, $aData);
     }
 
