@@ -20,29 +20,12 @@
 hasFormValidation= typeof document.createElement( 'input' ).checkValidity == 'function';
 
 $(document).ready(function(){
+
     initializeAjaxProgress();
     tableCellAdapters();
-    if(typeof(userdateformat) !== 'undefined')
-        {
-        $(".popupdate").each(function(i,e) {
-            format=$('#dateformat'+e.name).val();
-            if(!format) format = userdateformat;
-            $(e).datepicker({ dateFormat: format,
-                showOn: 'button',
-                changeYear: true,
-                changeMonth: true,
-                duration: 'fast'
-            }, $.datepicker.regional[userlanguage]);
-        });
-        $(".popupdatetime").datepicker({ dateFormat: userdateformat+' 00:00',
-            showOn: 'button',
-            changeYear: true,
-            changeMonth: true,
-            duration: 'fast'
-        }, $.datepicker.regional[userlanguage]);
-    }
-    $(".sf-menu").superfish({speed: 'fast'});
+    linksInDialog();
     doToolTip();
+
     $('button,input[type=submit],input[type=button],input[type=reset],.button').button();
     $('button,input[type=submit],input[type=button],input[type=reset],.button').addClass("limebutton");
 
@@ -61,7 +44,64 @@ $(document).ready(function(){
     });
 
 
-    if ($('#showadvancedattributes').length>0) updatequestionattributes();
+
+    if($('#survey-grid').length>0)
+    {
+        $(document).on('click', '.has-link', function () {
+            $linkUrl = $(this).find('a').attr('href');
+            window.location.href=$linkUrl;
+            console.log($linkUrl);
+        });
+    }
+
+    /* Switch format group */
+    if ($('#switchchangeformat').length>0){
+        $('#switchchangeformat button').on('click', function(event, state) {
+            $('#switchchangeformat button.active').removeClass('active');
+            $(this).addClass('active');
+            $value = $(this).data('value');
+            $url = $('#switch-url').attr('data-url')+'/format/'+$value;
+
+            console.log('required format: '+$value);
+            console.log('format url: '+$url);
+
+            $.ajax({
+                url : $url,
+                type : 'GET',
+                dataType : 'html',
+
+                // html contains the buttons
+                success : function(html, statut){
+                },
+                error :  function(html, statut){
+                    alert('error');
+                }
+            });
+
+        });
+    };
+
+
+    $('#survey-action-chevron').click(function(){
+        $url = $(this).data('url');
+        $.ajax({
+            url : $url,
+            type : 'GET',
+            dataType : 'html',
+
+            // html contains the buttons
+            success : function(html, statut){
+                $('#survey-action-container').animate({
+            "height": "toggle", "opacity": "toggle"
+        });
+                $('#survey-action-chevron').toggleClass('glyphicon-chevron-right').toggleClass('glyphicon-chevron-down');
+            },
+            error :  function(html, statut){
+                alert('error');
+            }
+        });
+    });
+
 
     $('#showadvancedattributes').click(function(){
         $('#showadvancedattributes').hide();
@@ -70,7 +110,8 @@ $(document).ready(function(){
             "height": "toggle", "opacity": "toggle"
         });
 
-    })
+    });
+
     $('#hideadvancedattributes').click(function(){
         $('#showadvancedattributes').show();
         $('#hideadvancedattributes').hide();
@@ -78,16 +119,32 @@ $(document).ready(function(){
             "height": "toggle", "opacity": "toggle"
         });
 
-    })
+    });
     $('#question_type').change(updatequestionattributes);
 
+    $('#question_type_button  li a').click(function(){
+        $(".btn:first-child .buttontext").text($(this).text());
+        $('#question_type').val($(this).data('value'));
+
+        updatequestionattributes();
+       });
+
     $('#MinimizeGroupWindow').click(function(){
         $('#groupdetails').hide();
     });
     $('#MaximizeGroupWindow').click(function(){
         $('#groupdetails').show();
     });
-    $('#tabs').tabs();
+    $('#tabs').tabs({
+        activate: function(event, ui) {
+            if(history.pushState) {
+                history.pushState(null, null, '#'+ui.newPanel.attr('id'));
+            }
+            else {
+                location.hash = ui.newPanel.attr('id');
+            }
+        }
+    });
     $('.tab-nav').tabs();
     $(".flashmessage").each(function() {
         $(this).notify().notify('create','themeroller',{},{custom:true,
@@ -95,20 +152,13 @@ $(document).ready(function(){
         expires: 5000
         });
     });
-    if ($("#question_type").not('.none').length > 0 && $("#question_type").attr('type')!='hidden'){
+    if ($("#question_type_button").not('.none').length > 0 && $("#question_type_button").attr('type')!='hidden'){
 
-        /*
-        $("#question_type").msDropDown({
-            'on' : {
-                'create' :qTypeDropdownInit
-            }
-        });
-        */
        qTypeDropdownInit();
-        $("#question_type").change(function(event){
+        $("#question_type_button").change(function(event){
             OtherSelection(this.value);
         });
-        $("#question_type").change();
+        $("#question_type_button").change();
     }
     else
     {
@@ -117,24 +167,114 @@ $(document).ready(function(){
         });
         $("#question_type.none").change();
     }
+
+    /**
+     * Confirmation modal
+     *
+     * Either provide a data-href to redirect after OK button is clicked,
+     * or data-onclick to be run when OK is clicked.
+     */
+    $('#confirmation-modal').on('show.bs.modal', function(e) {
+
+        var onclick = null;
+        var href = null;
+        if($(this).data('href'))
+        {
+            var href = $(this).data('href');    // When calling modal from javascript
+        }
+        else
+        {
+            var href = $(e.relatedTarget).data('href');
+        }
+
+        if($(this).data('onclick'))
+        {
+            var onclick = $(this).data('onclick');
+        }
+        else
+        {
+            var onclick = $(e.relatedTarget).data('onclick');
+        }
+
+        $keepopen = $(this).data('keepopen');
+        if (href != '' && href !== undefined)
+        {
+            $(this).find('.btn-ok').attr('href', href);
+        }
+        else if (onclick != '' && onclick !== undefined) {
+
+            var onclick_fn = eval(onclick);
+
+            if (typeof onclick_fn == 'function') {
+                $(this).find('.btn-ok').off('click');
+                $(this).find('.btn-ok').on('click', function(ev) {
+                    if(! $keepopen )
+                    {
+                        $('#confirmation-modal').modal('hide');
+                    }
+                    onclick_fn();
+                });
+            }
+            else {
+                throw "Confirmation modal: onclick is not a function.";
+            }
+
+        }
+        else if($(e.relatedTarget).data('ajax-url'))
+        {
+            var postDatas   = $(e.relatedTarget).data('post');
+            var gridid      = $(e.relatedTarget).data('gridid');
+
+            $(this).find('.btn-ok').on('click', function(ev)
+            {
+                $.ajax({
+                    type: "POST",
+                    url: $(e.relatedTarget).data('ajax-url'),
+                    data: postDatas,
+
+                    success : function(html, statut)
+                    {
+                        $.fn.yiiGridView.update(gridid);                   // Update the surveys list
+                        $('#confirmation-modal').modal('hide');
+                    },
+                    error :  function(html, statut){
+                        $('#confirmation-modal .modal-body-text').append(html.responseText);
+                    }
+
+                });
+            });
+        }
+        else
+        {
+            throw "Confirmation modal: Found neither data-href or data-onclick.";
+        }
+
+        $(this).find('.modal-body-text').html($(e.relatedTarget).data('message'));
+    });
+
+    // Error modal
+    $('#error-modal').on('show.bs.modal', function(e) {
+        $(this).find('.modal-body-text').html($(e.relatedTarget).data('message'));
+    });
+
 });
 
 function qTypeDropdownInit()
 {
     $(document).ready(function () {
-        $("#question_type option").each(function(index,element){
+        $("#question_type_button .questionType").each(function(index,element){
             $(element).qtip({
                 style: {
-                    classes: 'qtip-questiontype'
+                    classes: 'qtip-bootstrap'
                 },
                 content: getToolTip($(element).text()),
                 position: {
-                    my : 'top left',
-                    at: 'top right',
+                    my : 'center right',
+                    at: 'center left',
                     target: $('label[for=question_type]'),
                     viewport: $(window),
                     adjust: {
-                        x: 20
+                        x: 0
                     }
 
                 }
@@ -143,22 +283,15 @@ function qTypeDropdownInit()
         });
     });
     $(document).ready(function() {
-        $('body').on('mouseenter mouseleave', 'li.questionType', function(e) {
-            if (e.type == 'mouseenter')
-            {
-				// Hide all others if we show a new one.
-                $('#question_type option').qtip('hide');
-                $($(e.currentTarget).data().select2Data.element).qtip('option', 'position.target', $(e.currentTarget)).qtip('show');
-            }
-            else
-            {
-                $($(e.currentTarget).data().select2Data.element).qtip('hide');
-            }
-            
-            
+
+        $('.questionType').on('mouseenter', function(e){
+            //alert($(this).attr('class'));
+            $('.questionType').qtip('hide');
+            $(this).qtip('option', 'position.target', $(this).qtip('show'));
         });
-        $('#question_type').on('close', function(e) {
-            $('#question_type option').qtip('hide');
+
+        $('.questionType').on('mouseleave', function(e){
+            $(this).qtip('hide');
         });
     });
 }
@@ -187,6 +320,7 @@ function getToolTip(type){
         }
         return returnval;
     }
+
     return "<img src='" + imgurl + "/screenshots/"+code+".png' />";
 }
 
@@ -194,6 +328,9 @@ function getToolTip(type){
 
 function updatequestionattributes()
 {
+    var type = $('#question_type').val();
+    OtherSelection(type);
+
     $('.loader').show();
     $('#advancedquestionsettings').html('');
     var selected_value = qDescToCode[''+$("#question_type_child .selected").text()];
@@ -228,7 +365,7 @@ function updatequestionattributes()
 function validatefilename (form, strmessage )
 {
     if (form.the_file.value == "") {
-        alert( strmessage );
+        $('#pleaseselectfile-popup').modal();
         form.the_file.focus();
         return false ;
     }
@@ -237,6 +374,17 @@ function validatefilename (form, strmessage )
 
 function doToolTip()
 {
+    $('.btntooltip').tooltip();
+
+    // Since you can only have one option per data-toggle,
+    // we need this to enable both modal and toggle on one
+    // button. E.g., <button data-toggle='modal' data-tooltip='true' title="foo">...</button>
+    $('[data-tooltip="true"]').tooltip();
+
+    $(function () {
+        $('[data-toggle="tooltip"]').tooltip()
+    })
+
     // ToolTip on menu
     $(".sf-menu li").each(function() {
         tipcontent=$(this).children("a").children("img").attr('alt');
@@ -253,117 +401,14 @@ function doToolTip()
                     at: "top right"
                 }
             });
-        }
-    });
-    $(".sf-menu a > img[alt]").removeAttr("alt");
-    $("a").each(function() {
-        tipcontent=$(this).children("img").attr('alt');
-        if(!tipcontent){tipcontent=htmlEncode($(this).attr('title'));}
-        if(tipcontent && tipcontent!=""){
-            $(this).qtip({
-                content: {
-                    text: tipcontent
-                },
-                style: {
-                    classes: "qtip-light qtip-rounded"
-                },
-                position: {
-                    viewport: $(window),
-                    at: 'bottom right'
-                }
-            });
-        }
-    });
-    $("a > img[alt]").removeAttr("alt");
-    
-    // Call the popuptip hover rel attribute
-    $('.popuptip').each(function(){
-        if($(this).attr('rel')){
-            htmlcontent=$(this).html();
-            tiptarget=$("#"+$(this).attr('rel'));
-            //if($("#"+$(this).attr('rel')).find('img').length==1){ tiptarget=$("#"+$(this).attr('rel')).find('img');}
-            tiptarget.qtip({
-                content: {
-                    text: htmlcontent
-                },
-                style: {
-                    classes: "qtip-light qtip-rounded"
-                },
-                position: {
-                    at: "bottom center",
-                    my: "top center"
-                },
-                hide: {
-                    fixed: true,
-                    delay: 500,
-                    event: "mouseout"
-                }
-            });
-            $("#"+$(this).attr('rel')).find("img").removeAttr("alt"); // Remove children img attr alt, the  default tooltip can apply.
-        }
-    });
-    // On label
-    $('label[title]').each(function() {
-        if($(this).attr('title') != '')
-            {
-            $(this).qtip({
-                style: {
-                    classes: "qtip-cream qtip-rounded"
-                },
-                position: {
-                    viewport: $(window),
-                    at: "bottom right"
-                }
-            });
-        }
-    });
-    // Loads the tooltips on image
-    $('img[alt],input[src]').each(function() {
-        if($(this).attr('alt') != ''){
-            $(this).qtip({
-                content: {
-                    attr: "alt"
-                },
-                style: {
-                    classes: "qtip-light qtip-rounded"
-                },
-                position: {
-                    viewport: $(window),
-                    at: "bottom right"
-                },
-                hide: {
-                    event: "mouseout"
-                }
-            });
+            $(this).children("a").children("img").removeAttr('title');
         }
     });
 
-    //Still used ?
-    $('.tipme').each(function() {
-        if($(this).attr('alt') != '')
-            {
-            $(this).qtip(
-            {
-                content: {
-                    attr: 'alt'
-                },
-                style: {
-                    classes: "qtip-cream qtip-rounded"
-                },
-                position: {
-                        viewport: $(window),
-                        at: 'top right',
-                        tooltip: 'bottom left'
-                    }
-            });
-        }
-    });
+
 
 }
-// A function to encode any HTML for qtip
-function htmlEncode(html){
-  return $('<div/>').text(html).html();
-}
+
 // If the length of the element's string is 0 then display helper message
 function isEmpty(elem, helperMsg)
 {
@@ -387,6 +432,23 @@ function arrHasDupes( A ) {                          // finds any duplicate arra
     return false;
 }
 
+/**
+ * Like arrHasDupes, but returns the duplicated item
+ *
+ * @param {array} A
+ * @return {mixed|boolean} Array item] or false if no duplicate is found
+ */
+function arrHasDupesWhich(A) {
+    var i, j, n;
+    n=A.length;
+    // to ensure the fewest possible comparisons
+    for (i=0; i<n; i++) {                        // outer loop uses each item i at 0 through n
+        for (j=i+1; j<n; j++) {              // inner loop only compares items j at i+1 to n
+            if (A[i]==A[j]) return A[i];
+    }}
+    return false;
+}
+
 
 // (c) 2006 Simon Wunderlin, License: GPL, hacks want to be free ;)
 // This fix forces Firefox to fire the onchange event if someone changes select box with cursor keys
@@ -399,13 +461,6 @@ function ev_gecko_select_keyup_ev(Ev) {
     return true;
 }
 
-function init_gecko_select_hack() {
-    return true;
-    var selects = document.getElementsByTagName("SELECT");
-    for(i=0; i<selects.length; i++)
-        selects.item(i).addEventListener("keyup", ev_gecko_select_keyup_ev, false);
-    return true;
-}
 
 
 function getkey(e)
@@ -440,10 +495,6 @@ function goodchars(e, goods)
 }
 
 
-function trim(stringToTrim) {
-    return stringToTrim.replace(/^\s+|\s+$/g,"");
-}
-
 function DoAdd()
 {
     if (document.getElementById("available_languages").selectedIndex>-1)
@@ -472,7 +523,32 @@ function DoRemove(minItems,strmsg)
         if (strmsg!=''){alert(strmsg);}
 }
 
+function UpdateLanguageIDs(mylangs,confirmtxt)
+{
+    document.getElementById("languageids").value = '';
 
+    var lbBox = document.getElementById("additional_languages");
+    for (var i = 0; i < lbBox.options.length; i++)
+        {
+        document.getElementById("languageids").value = document.getElementById("languageids").value + lbBox.options[i].value+ ' ';
+    }
+    if (mylangs)
+        {
+        if (checklangs(mylangs))
+            {
+            return true;
+        } else
+            {
+            return confirm(confirmtxt);
+        }
+    }
+}
+
+
+
+function trim(stringToTrim) {
+    return stringToTrim.replace(/^\s+|\s+$/g,"");
+}
 
 function AddItem(objListBox, strText, strId)
 {
@@ -502,28 +578,6 @@ function GetItemIndex(objListBox, strId)
     return -1;
 }
 
-
-function UpdateLanguageIDs(mylangs,confirmtxt)
-{
-    document.getElementById("languageids").value = '';
-
-    var lbBox = document.getElementById("additional_languages");
-    for (var i = 0; i < lbBox.options.length; i++)
-        {
-        document.getElementById("languageids").value = document.getElementById("languageids").value + lbBox.options[i].value+ ' ';
-    }
-    if (mylangs)
-        {
-        if (checklangs(mylangs))
-            {
-            return true;
-        } else
-            {
-            return confirm(confirmtxt);
-        }
-    }
-}
-
 function compareText (option1, option2) {
     return option1.text < option2.text ? -1 :
     option1.text > option2.text ? 1 : 0;
@@ -677,31 +731,45 @@ jQuery.fn.center = function () {
     this.css("top", ( $(window).height() - this.height() ) / 2+$(window).scrollTop() + "px");
     this.css("left", ( $(window).width() - this.width() ) / 2+$(window).scrollLeft() + "px");
     return this;
-}
+};
 
 // Fix broken substr function with negative start value (in older IE)
 // From https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/substr
 if ('ab'.substr(-1) != 'b') {
-	String.prototype.substr = function(substr) {
-		return function(start, length) {
-			if (start < 0) start = this.length + start;
-			return substr.call(this, start, length);
-		}
-	}(String.prototype.substr);
+    String.prototype.substr = function(substr) {
+        return function(start, length) {
+            if (start < 0) start = this.length + start;
+            return substr.call(this, start, length);
+        };
+    }(String.prototype.substr);
 }
 
-/**
-* Yii CSRF protection divs breaks this script so this function moves the 
-* hidden CSRF field out of the div and remove it if needed
-* 140207 : Why this function is needed ? Where is the script broken ?
-*/
-function removeCSRFDivs()
+function linksInDialog()
 {
-    $('input[name=YII_CSRF_TOKEN]').each(function(){
-       var parent = $(this).parent();
-       var grandfather = $(parent).parent();
-       $(grandfather).append(this);
-       $(parent).remove();
+    $(function () {
+        var iframe = $('<iframe id="dialog" allowfullscreen></iframe>');
+        var dialog = $("<div></div>").append(iframe).appendTo("body").dialog({
+            autoOpen: false,
+            modal: false,
+            resizable: true,
+            width: "60%",
+            height: $(window).height()*0.6,
+            close: function () {
+                iframe.attr("src", "");
+            }
+        });
+        $(document).on('click','a[target=dialog]',function(event){
+            event.preventDefault();
+            var src = $(this).attr("href");
+            var title = $(this).attr("title");
+            if(!title && $(this).children("img[alt]"))
+                title = $(this).children("img[alt]").attr("alt");
+            iframe.attr({
+                src: src,
+            });
+            dialog.dialog("option", "title", title);
+            dialog.dialog("open");
+        });
     });
 }
 
@@ -721,7 +789,7 @@ function initializeAjaxProgress()
     });
     $('#ajaxprogress').bind('ajaxStop', function()
     {
-        
+
         $(this).dialog('close');
     });
 }
@@ -764,6 +832,7 @@ function sendPost(myaction,checkcode,arrayparam,arrayval)
     $form.appendTo("body");
     $form.submit();
 }
+
 function addHiddenElement(theform,thename,thevalue)
 {
     var myel = document.createElement('input');
@@ -773,8 +842,7 @@ function addHiddenElement(theform,thename,thevalue)
     myel.value = thevalue;
     return myel;
 }
-function onlyUnique(value, index, self) { 
+
+function onlyUnique(value, index, self) {
     return self.indexOf(value) === index;
 }
-
-// @license-end
