@@ -4,14 +4,12 @@
  * This JavaScript will reload the grid on page size change
  */
 
-$(document).ready(function() {
+$(document).on('ready  pjax:scriptcomplete', function() {
     jQuery(function($)
     {
         jQuery(document).on("change", '#pageSize', function()
         {
-            console.log("page size changed");
-            console.log($(this).val());
-            $.fn.yiiGridView.update('survey-grid',{ data:{ pageSize: $(this).val() }});
+            $('#survey-grid').yiiGridView('update',{ data:{ pageSize: $(this).val() }});
         });
     });
 });
