@@ -1,22 +1,21 @@
 <?php
 /*
  * LimeSurvey
- * Copyright (C) 2007-2011 The LimeSurvey Project Team / Carsten Schmitz
+ * Copyright (C) 2007-2020 The LimeSurvey Project Team / Carsten Schmitz
  * All rights reserved.
- * License: GNU/GPL License v2 or later, see LICENSE.php
+ * License: GNU/GPL License v3 or later, see LICENSE.php
  * LimeSurvey is free software. This version may have been modified pursuant
  * to the GNU General Public License, and as distributed it includes or
  * is derivative of works licensed under the GNU General Public License or
  * other free or open source software licenses.
  * See COPYRIGHT.php for copyright notices and details.
- *150413
  */
 
-$config['versionnumber'] = '2.51.3';
-$config['dbversionnumber'] = 260;
-$config['buildnumber'] = '160907';
-$config['updatable'] = true;
-$config['assetsversionnumber'] = '32';
-return $config;
 
-?>
+$config['versionnumber'] = '3.26.2';
+$config['dbversionnumber'] = 365;
+$config['buildnumber'] = 210503;
+$config['updatable'] = true;
+$config['templateapiversion'] = 3;
+$config['assetsversionnumber'] = '30187';
+return $config;
