@@ -1,5 +1,5 @@
 <?php
-class AuthLDAP extends ls\pluginmanager\AuthPluginBase
+class AuthLDAP extends LimeSurvey\PluginManager\AuthPluginBase
 {
     protected $storage = 'DbStorage';
 
@@ -17,26 +17,26 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
     protected $settings = array(
         'server' => array(
             'type' => 'string',
-            'label' => 'Ldap server',
+            'label' => 'LDAP server',
             'help' => 'e.g. ldap://ldap.example.com or ldaps://ldap.example.com'
-            ),
+        ),
         'ldapport' => array(
             'type' => 'string',
             'label' => 'Port number',
             'help' => 'Default when omitted is 389',
-            ),
+        ),
         'ldapversion' => array(
             'type' => 'select',
             'label' => 'LDAP version',
             'options' => array('2' => 'LDAPv2', '3'  => 'LDAPv3'),
             'default' => '2',
             'submitonchange'=> true
-            ),
+        ),
         'ldapoptreferrals' => array(
             'type' => 'boolean',
             'label' => 'Select true if referrals must be followed (use false for ActiveDirectory)',
             'default' => '0'
-            ),
+        ),
         'ldaptls' => array(
             'type' => 'boolean',
             'help' => 'Check to enable Start-TLS encryption, when using LDAPv3',
@@ -56,89 +56,142 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
             'help' => 'e.g. cn= or uid=',
             ),
         'domainsuffix' => array(
-                'type' => 'string',
-                'label' => 'Username suffix',
-                'help' => 'e.g. @mydomain.com or remaining part of ldap query',
-                ),
+            'type' => 'string',
+            'label' => 'Username suffix',
+            'help' => 'e.g. @mydomain.com or remaining part of ldap query',
+        ),
         'searchuserattribute' => array(
-                'type' => 'string',
-                'label' => 'Attribute to compare to the given login can be uid, cn, mail, ...'
-                ),
+            'type' => 'string',
+            'label' => 'Attribute to compare to the given login can be uid, cn, mail, ...'
+        ),
         'usersearchbase' => array(
-                'type' => 'string',
-                'label' => 'Base DN for the user search operation'
-                ),
+            'type' => 'string',
+            'label' => 'Base DN for the user search operation. Multiple bases may be separated by a semicolon (;)'
+        ),
         'extrauserfilter' => array(
-                'type' => 'string',
-                'label' => 'Optional extra LDAP filter to be ANDed to the basic (searchuserattribute=username) filter. Don\'t forget the outmost enclosing parentheses'
-                ),
+            'type' => 'string',
+            'label' => 'Optional extra LDAP filter to be ANDed to the basic (searchuserattribute=username) filter. Don\'t forget the outmost enclosing parentheses'
+        ),
         'binddn' => array(
-                'type' => 'string',
-                'label' => 'Optional DN of the LDAP account used to search for the end-user\'s DN. An anonymous bind is performed if empty.'
-                ),
+            'type' => 'string',
+            'label' => 'Optional DN of the LDAP account used to search for the end-user\'s DN. An anonymous bind is performed if empty.'
+        ),
         'bindpwd' => array(
-                'type' => 'password',
-                'label' => 'Password of the LDAP account used to search for the end-user\'s DN if previoulsy set.'
-                ),
+            'type' => 'password',
+            'label' => 'Password of the LDAP account used to search for the end-user\'s DN if previoulsy set.'
+        ),
         'mailattribute' => array(
-                'type' => 'string',
-                'label' => 'LDAP attribute of email address'
-                ),
+            'type' => 'string',
+            'label' => 'LDAP attribute of email address'
+        ),
         'fullnameattribute' => array(
-                'type' => 'string',
-                'label' => 'LDAP attribute of full name'
-                ),
+            'type' => 'string',
+            'label' => 'LDAP attribute of full name'
+        ),
         'is_default' => array(
-                'type' => 'checkbox',
-                'label' => 'Check to make default authentication method'
-                ),
+            'type' => 'checkbox',
+            'label' => 'Check to make default authentication method'
+        ),
         'autocreate' => array(
-                'type' => 'checkbox',
-                'label' => 'Automatically create user if it exists in LDAP server'
-                ),
+            'type' => 'checkbox',
+            'label' => 'Automatically create user if it exists in LDAP server'
+        ),
         'automaticsurveycreation' => array(
-                'type' => 'checkbox',
-                'label' => 'Grant survey creation permission to automatically created users'
-                )
+            'type' => 'checkbox',
+            'label' => 'Grant survey creation permission to automatically created users'
+        ),
+        'groupsearchbase' => array(
+            'type' => 'string',
+            'label' => 'Optional base DN for group restriction',
+            'help' => 'E.g., ou=Groups,dc=example,dc=com'
+        ),
+        'groupsearchfilter' => array(
+            'type' => 'string',
+            'label' => 'Optional filter for group restriction',
+            'help' => 'Required if group search base set. E.g. (&(cn=limesurvey)(memberUid=$username)) or (&(cn=limesurvey)(member=$userdn))'
+        ),
+        'allowInitialUser' => array(
+            'type' => 'checkbox',
+            'label' => 'Allow initial user to login via LDAP',
+        )
     );
 
-    public function init() {
+    public function init()
+    {
         /**
          * Here you should handle subscribing to the events your plugin will handle
          */
         $this->subscribe('beforeActivate');
+        $this->subscribe('getGlobalBasePermissions');
+        $this->subscribe('beforeHasPermission');
         $this->subscribe('createNewUser');
         $this->subscribe('beforeLogin');
         $this->subscribe('newLoginForm');
         $this->subscribe('afterLoginFormSubmit');
+        $this->subscribe('remoteControlLogin');
+
         $this->subscribe('newUserSession');
     }
 
     /**
      * Check availability of LDAP Apache Module
      *
-     * @return unknown_type
+     * @return void
      */
     public function beforeActivate()
     {
-        if (!function_exists("ldap_connect")){
+        if (!function_exists("ldap_connect")) {
             $event = $this->getEvent();
             $event->set('success', false);
-
             $event->set('message', gT("LDAP authentication failed: LDAP PHP module is not available."));
         }
     }
 
+    /**
+     * Add AuthLDAP Permission to global Permission
+     * @return void
+     */
+    public function getGlobalBasePermissions()
+    {
+        $this->getEvent()->append('globalBasePermissions', array(
+            'auth_ldap' => array(
+                'create' => false,
+                'update' => false,
+                'delete' => false,
+                'import' => false,
+                'export' => false,
+                'title' => gT("Use LDAP authentication"),
+                'description' => gT("Use LDAP authentication"),
+                'img' => 'usergroup'
+            ),
+        ));
+    }
+
+    /**
+     * Validation of AuthPermission (for super-admin only)
+     * @return void
+     */
+    public function beforeHasPermission()
+    {
+        $oEvent = $this->getEvent();
+        if ($oEvent->get('sEntityName') != 'global' || $oEvent->get('sPermission') != 'auth_ldap' || $oEvent->get('sCRUD') != 'read') {
+            return;
+        }
+        $iUserId = Permission::getUserId($oEvent->get('iUserID'));
+        if ($iUserId == 1) {
+            $oEvent->set('bPermission', (bool) $this->get('allowInitialUser'));
+        }
+    }
+
     /**
      * Create a LDAP user
      *
-     * @return unknown_type
+     * @return void
      */
     public function createNewUser()
     {
         // Do nothing if the user to be added is not LDAP type
-        if (flattenText(Yii::app()->request->getPost('user_type')) != 'LDAP')
-        {
+        if (flattenText(Yii::app()->request->getPost('user_type')) != 'LDAP') {
             return;
         }
 
@@ -149,19 +202,17 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
      * Create a LDAP user
      *
      * @param string $new_user
-     * @return null|string New user ID
+     * @return null|integer New user ID
      */
     private function _createNewUser($new_user)
     {
         $oEvent = $this->getEvent();
 
         // Get configuration settings:
-        $ldapserver     = $this->get('server');
-        $ldapport       = $this->get('ldapport');
-        $ldapmode       = $this->get('ldapmode');
-        $searchuserattribute    = $this->get('searchuserattribute');
-        $extrauserfilter      = $this->get('extrauserfilter');
-        $usersearchbase   = $this->get('usersearchbase');
+        $ldapmode = $this->get('ldapmode');
+        $searchuserattribute = $this->get('searchuserattribute');
+        $extrauserfilter = $this->get('extrauserfilter');
+        $usersearchbase = $this->get('usersearchbase');
         $binddn         = $this->get('binddn');
         $bindpwd        = $this->get('bindpwd');
         $mailattribute = $this->get('mailattribute');
@@ -169,101 +220,90 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
 
         // Try to connect
         $ldapconn = $this->createConnection();
-        if (!is_resource($ldapconn))
-        {
-            $oEvent->set('errorCode',self::ERROR_LDAP_CONNECTION);
-            $oEvent->set('errorMessageTitle','');
-            $oEvent->set('errorMessageBody',$ldapconn['errorMessage']);
+        if (!is_resource($ldapconn)) {
+            $oEvent->set('errorCode', self::ERROR_LDAP_CONNECTION);
+            $oEvent->set('errorMessageTitle', '');
+            $oEvent->set('errorMessageBody', $ldapconn['errorMessage']);
             return null;
         }
 
-        if (empty($ldapmode) || $ldapmode=='simplebind')
-        {
-            $oEvent->set('errorCode',self::ERROR_LDAP_MODE);
-            $oEvent->set('errorMessageTitle',gT("Failed to add user"));
-            $oEvent->set('errorMessageBody',gT("Simple bind LDAP configuration doesn't allow LDAP user creation"));
+        if (empty($ldapmode) || $ldapmode == 'simplebind') {
+            $oEvent->set('errorCode', self::ERROR_LDAP_MODE);
+            $oEvent->set('errorMessageTitle', gT("Failed to add user"));
+            $oEvent->set('errorMessageBody', gT("Simple bind LDAP configuration doesn't allow LDAP user creation"));
             return null;
         }
 
         // Search email address and full name
-        if (empty($binddn))
-        {
+        if (empty($binddn)) {
             // There is no account defined to do the LDAP search,
             // let's use anonymous bind instead
             $ldapbindsearch = @ldap_bind($ldapconn);
-        }
-       else
-        {
+        } else {
             // An account is defined to do the LDAP search, let's use it
             $ldapbindsearch = @ldap_bind($ldapconn, $binddn, $bindpwd);
         }
         if (!$ldapbindsearch) {
-            $oEvent->set('errorCode',self::ERROR_LDAP_NO_BIND);
-            $oEvent->set('errorMessageTitle',gT('Could not connect to LDAP server.'));
-            $oEvent->set('errorMessageBody',gT(ldap_error($ldapconn)));
+            $oEvent->set('errorCode', self::ERROR_LDAP_NO_BIND);
+            $oEvent->set('errorMessageTitle', gT('Could not connect to LDAP server.'));
+            $oEvent->set('errorMessageBody', gT(ldap_error($ldapconn)));
             ldap_close($ldapconn); // all done? close connection
             return null;
         }
         // Now prepare the search fitler
-        if ( $extrauserfilter != "")
-        {
+        if ($extrauserfilter != "") {
             $usersearchfilter = "(&($searchuserattribute=$new_user)$extrauserfilter)";
-        }
-        else
-        {
+        } else {
             $usersearchfilter = "($searchuserattribute=$new_user)";
         }
         // Search for the user
-        $dnsearchres = ldap_search($ldapconn, $usersearchbase, $usersearchfilter, array($mailattribute,$fullnameattribute));
-        $rescount=ldap_count_entries($ldapconn,$dnsearchres);
-        if ($rescount == 1)
-        {
-            $userentry=ldap_get_entries($ldapconn, $dnsearchres);
-            $new_email = flattenText($userentry[0][$mailattribute][0]);
-            $new_full_name = flattenText($userentry[0][strtolower($fullnameattribute)][0]);
+        $userentry = false;
+        // try each semicolon-separated search base in order
+        foreach (explode(";", $usersearchbase) as $usb) {
+            $dnsearchres = ldap_search($ldapconn, $usb, $usersearchfilter, array($mailattribute, $fullnameattribute));
+            $rescount = ldap_count_entries($ldapconn, $dnsearchres);
+            if ($rescount == 1) {
+                $userentry = ldap_get_entries($ldapconn, $dnsearchres);
+                $new_email = flattenText($userentry[0][strtolower($mailattribute)][0]);
+                $new_full_name = flattenText($userentry[0][strtolower($fullnameattribute)][0]);
+                break;
+            }
         }
-        else
-        {
-            $oEvent->set('errorCode',self::ERROR_LDAP_NO_SEARCH_RESULT);
-            $oEvent->set('errorMessageTitle',gT('Username not found in LDAP server'));
-            $oEvent->set('errorMessageBody',gT('Verify username and try again'));
+        if (!$userentry) {
+            $oEvent->set('errorCode', self::ERROR_LDAP_NO_SEARCH_RESULT);
+            $oEvent->set('errorMessageTitle', gT('Username not found in LDAP server'));
+            $oEvent->set('errorMessageBody', gT('Verify username and try again'));
             ldap_close($ldapconn); // all done? close connection
             return null;
         }
 
-        if (!validateEmailAddress($new_email))
-        {
-            $oEvent->set('errorCode',self::ERROR_INVALID_EMAIL);
-            $oEvent->set('errorMessageTitle',gT("Failed to add user"));
-            $oEvent->set('errorMessageBody',gT("The email address is not valid."));
+        if (!validateEmailAddress($new_email)) {
+            $oEvent->set('errorCode', self::ERROR_INVALID_EMAIL);
+            $oEvent->set('errorMessageTitle', gT("Failed to add user"));
+            $oEvent->set('errorMessageBody', gT("The email address is not valid."));
             return null;
         }
         $new_pass = createPassword();
         // If user is being auto created we set parent ID to 1 (admin user)
-        if (isset(Yii::app()->session['loginID']))
-        {
+        if (isset(Yii::app()->session['loginID'])) {
             $parentID = Yii::app()->session['loginID'];
-        }
-        else
-        {
+        } else {
             $parentID = 1;
         }
         $iNewUID = User::model()->insertUser($new_user, $new_pass, $new_full_name, $parentID, $new_email);
-        if (!$iNewUID)
-        {
-            $oEvent->set('errorCode',self::ERROR_ALREADY_EXISTING_USER);
-            $oEvent->set('errorMessageTitle','');
-            $oEvent->set('errorMessageBody',gT("Failed to add user"));
+        if (!$iNewUID) {
+            $oEvent->set('errorCode', self::ERROR_ALREADY_EXISTING_USER);
+            $oEvent->set('errorMessageTitle', '');
+            $oEvent->set('errorMessageBody', gT("Failed to add user"));
             return null;
         }
+        Permission::model()->setGlobalPermission($iNewUID, 'auth_ldap');
 
-        Permission::model()->setGlobalPermission($iNewUID,'auth_ldap');
-
-        $oEvent->set('newUserID',$iNewUID);
-        $oEvent->set('newPassword',$new_pass);
-        $oEvent->set('newEmail',$new_email);
-        $oEvent->set('newFullName',$new_full_name);
-        $oEvent->set('errorCode',self::ERROR_NONE);
+        $oEvent->set('newUserID', $iNewUID);
+        $oEvent->set('newPassword', $new_pass);
+        $oEvent->set('newEmail', $new_email);
+        $oEvent->set('newFullName', $new_full_name);
+        $oEvent->set('errorCode', self::ERROR_NONE);
         return $iNewUID;
     }
 
@@ -288,12 +328,11 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
         // Try to connect
         $ldapconn = ldap_connect($ldapserver, (int) $ldapport);
         if (false == $ldapconn) {
-            return array( "errorCode" => 1, "errorMessage" => gT('Error creating LDAP connection') );
+            return array("errorCode" => 1, "errorMessage" => gT('Error creating LDAP connection'));
         }
 
         // using LDAP version
-        if ($ldapver === null)
-        {
+        if ($ldapver === null) {
             // If the version hasn't been set, default = 2
             $ldapver = 2;
         }
@@ -301,13 +340,11 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
         ldap_set_option($ldapconn, LDAP_OPT_PROTOCOL_VERSION, $ldapver);
         ldap_set_option($ldapconn, LDAP_OPT_REFERRALS, $ldapoptreferrals);
 
-        if (!empty($ldaptls) && $ldaptls == '1' && $ldapver == 3 && preg_match("/^ldaps:\/\//", $ldapserver) == 0 )
-        {
+        if (!empty($ldaptls) && $ldaptls == '1' && $ldapver == 3 && preg_match("/^ldaps:\/\//", $ldapserver) == 0) {
             // starting TLS secure layer
-            if(!ldap_start_tls($ldapconn))
-            {
+            if (!ldap_start_tls($ldapconn)) {
                 ldap_close($ldapconn); // all done? close connection
-                return array( "errorCode" => 100, 'errorMessage' => ldap_error($ldapconn) );
+                return array("errorCode" => 100, 'errorMessage' => ldap_error($ldapconn));
             }
         }
 
@@ -325,8 +362,8 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
     public function newLoginForm()
     {
         $this->getEvent()->getContent($this)
-            ->addContent(CHtml::tag('li', array(), "<label for='user'>"  . gT("Username") . "</label><input name='user' id='user' type='text' size='40' maxlength='40' value='' />"))
-            ->addContent(CHtml::tag('li', array(), "<label for='password'>"  . gT("Password") . "</label><input name='password' id='password' type='password' size='40' maxlength='40' value='' />"));
+        ->addContent(CHtml::tag('span', array(), "<label for='user'>".gT("Username")."</label>".CHtml::textField('user', '', array('size'=>240, 'maxlength'=>240, 'class'=>"form-control"))))
+        ->addContent(CHtml::tag('span', array(), "<label for='password'>".gT("Password")."</label>".CHtml::passwordField('password', '', array('size'=>240, 'maxlength'=>240, 'class'=>"form-control"))));
     }
 
     /**
@@ -352,8 +389,8 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
                 $aPluginSettings['ldapversion']['current'] = $ldapver;
             }
 
-            if ($ldapver == '2' ) {
-               unset($aPluginSettings['ldaptls']);
+            if ($ldapver == '2') {
+                unset($aPluginSettings['ldaptls']);
             }
 
             if ($ldapmode == 'searchandbind') {
@@ -383,11 +420,11 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
     {
         // Do nothing if this user is not AuthLDAP type
         $identity = $this->getEvent()->get('identity');
-        if ($identity->plugin != 'AuthLDAP')
-        {
+        if ($identity->plugin != 'AuthLDAP') {
             return;
         }
-
+        /* unsubscribe from beforeHasPermission, else updating event */
+        $this->unsubscribe('beforeHasPermission');
         // Here we do the actual authentication
         $username = $this->getUsername();
         $password = $this->getPassword();
@@ -396,70 +433,62 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
         $autoCreateFlag = false;
         $user = $this->api->getUserByName($username);
         // No user found!
-        if ($user === null)
-        {
+        if ($user === null) {
             // If ldap mode is searchandbind and autocreation is enabled we can continue
-            if ($ldapmode=='searchandbind' && $this->get('autocreate', null, null, false) == true)
-            {
+            if ($ldapmode == 'searchandbind' && $this->get('autocreate', null, null, false) == true) {
                 $autoCreateFlag = true;
-            }
-            else
-            {
-              // If the user doesnt exist in the LS database, he can not login
-              $this->setAuthFailure(self::ERROR_USERNAME_INVALID);
-              return;
+            } else {
+                // If the user doesnt exist in the LS database, he can not login
+                $this->setAuthFailure(self::ERROR_USERNAME_INVALID); // Error shown : user or password invalid
+                return;
             }
         }
-        if ($user !== null && ($user->uid == 1 || !Permission::model()->hasGlobalPermission('auth_ldap','read',$user->uid)))
-        {
-            $this->setAuthFailure(self::ERROR_AUTH_METHOD_INVALID, gT('LDAP authentication method is not allowed for this user'));
-            return;
+        if ($user !== null) {
+            //If user cannot login via LDAP: setAuthFailure
+            if (($user->uid == 1 && !$this->get('allowInitialUser'))
+                || !Permission::model()->hasGlobalPermission('auth_ldap', 'read', $user->uid)
+            ) {
+                $this->setAuthFailure(self::ERROR_AUTH_METHOD_INVALID);  // Error shown : user or password invalid - swe how a generic message to prevent disclosure if user exists or not
+                return;
+            }
         }
 
-        if (empty($password))
-        {
+        if (empty($password)) {
             // If password is null or blank reject login
             // This is necessary because in simple bind ldap server authenticates with blank password
-            $this->setAuthFailure(self::ERROR_PASSWORD_INVALID);
+            $this->setAuthFailure(self::ERROR_PASSWORD_INVALID); // Error shown : user or password invalid
             return;
         }
 
         // Get configuration settings:
-        $ldapserver 		= $this->get('server');
-        $ldapport   		= $this->get('ldapport');
         $suffix     		= $this->get('domainsuffix');
         $prefix     		= $this->get('userprefix');
-        $searchuserattribute    = $this->get('searchuserattribute');
-        $extrauserfilter    	= $this->get('extrauserfilter');
-        $usersearchbase		= $this->get('usersearchbase');
-        $binddn     		= $this->get('binddn');
-        $bindpwd     		= $this->get('bindpwd');
+        $searchuserattribute = $this->get('searchuserattribute');
+        $extrauserfilter = $this->get('extrauserfilter');
+        $usersearchbase = $this->get('usersearchbase');
+        $binddn = $this->get('binddn');
+        $bindpwd = $this->get('bindpwd');
+        $groupsearchbase        = $this->get('groupsearchbase');
+        $groupsearchfilter      = $this->get('groupsearchfilter');
 
         // Try to connect
         $ldapconn = $this->createConnection();
-        if (!is_resource($ldapconn))
-        {
+        if (!is_resource($ldapconn)) {
             $this->setAuthFailure($ldapconn['errorCode'], gT($ldapconn['errorMessage']));
             return;
         }
 
-        if (empty($ldapmode) || $ldapmode=='simplebind')
-        {
+        if (empty($ldapmode) || $ldapmode == 'simplebind') {
             // in simple bind mode we know how to construct the userDN from the username
-            $ldapbind = @ldap_bind($ldapconn, $prefix . $username . $suffix, $password);
-        }
-        else
-        {
+            $ldapbind = @ldap_bind($ldapconn, $prefix.$username.$suffix, $password);
+        } else {
             // in search and bind mode we first do a LDAP search from the username given
             // to foind the userDN and then we procced to the bind operation
-            if (empty($binddn))
-            {
+            if (empty($binddn)) {
                 // There is no account defined to do the LDAP search,
                 // let's use anonymous bind instead
                 $ldapbindsearch = @ldap_bind($ldapconn);
-            }
-            else
-            {
+            } else {
                 // An account is defined to do the LDAP search, let's use it
                 $ldapbindsearch = @ldap_bind($ldapconn, $binddn, $bindpwd);
             }
@@ -469,24 +498,21 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
                 return;
             }
             // Now prepare the search fitler
-            if ( $extrauserfilter != "")
-            {
+            if ($extrauserfilter != "") {
                 $usersearchfilter = "(&($searchuserattribute=$username)$extrauserfilter)";
-            }
-            else
-            {
+            } else {
                 $usersearchfilter = "($searchuserattribute=$username)";
             }
             // Search for the user
-            $dnsearchres = ldap_search($ldapconn, $usersearchbase, $usersearchfilter, array($searchuserattribute));
-            $rescount=ldap_count_entries($ldapconn,$dnsearchres);
-            if ($rescount == 1)
-            {
-                $userentry=ldap_get_entries($ldapconn, $dnsearchres);
-                $userdn = $userentry[0]["dn"];
+            foreach (explode(";", $usersearchbase) as $usb) {
+                $dnsearchres = ldap_search($ldapconn, $usb, $usersearchfilter, array($searchuserattribute));
+                $rescount = ldap_count_entries($ldapconn, $dnsearchres);
+                if ($rescount == 1) {
+                    $userentry = ldap_get_entries($ldapconn, $dnsearchres);
+                    $userdn = $userentry[0]["dn"];
+                }
             }
-            else
-            {
+            if(!$userentry) {
                 // if no entry or more than one entry returned
                 // then deny authentication
                 $this->setAuthFailure(self::ERROR_USERNAME_INVALID);
@@ -494,6 +520,21 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
                 return;
             }
 
+            // If specifed, check group membership
+            if ($groupsearchbase != '' && $groupsearchfilter != '') {
+                $keywords = array('$username', '$userdn');
+                $substitutions = array($username, ldap_escape($userdn, "", LDAP_ESCAPE_FILTER));
+                $filter = str_replace($keywords, $substitutions, $groupsearchfilter);
+                $groupsearchres = ldap_search($ldapconn, $groupsearchbase, $filter);
+                $grouprescount = ldap_count_entries($ldapconn, $groupsearchres);
+                if ($grouprescount < 1) {
+                    $this->setAuthFailure(self::ERROR_USERNAME_INVALID,
+                    gT('Valid username but not authorized by group restriction'));
+                    ldap_close($ldapconn); // all done? close connection
+                    return;
+                }
+            }
+
             // binding to ldap server with the userDN and privided credentials
             $ldapbind = @ldap_bind($ldapconn, $userdn, $password);
         }
@@ -508,15 +549,12 @@ class AuthLDAP extends ls\pluginmanager\AuthPluginBase
         ldap_close($ldapconn); // all done? close connection
 
         // Finally, if user didn't exist and auto creation (i.e. autoCreateFlag == true) is enabled, we create it
-        if ($autoCreateFlag)
-        {
-            if (($iNewUID = $this->_createNewUser($username)) && $this->get('automaticsurveycreation', null, null, false))
-            {
+        if ($autoCreateFlag) {
+            if (($iNewUID = $this->_createNewUser($username)) && $this->get('automaticsurveycreation', null, null, false)) {
                 Permission::model()->setGlobalPermission($iNewUID, 'surveys', array('create_p'));
             }
             $user = $this->api->getUserByName($username);
-            if ($user === null)
-            {
+            if ($user === null) {
                 $this->setAuthFailure(self::ERROR_USERNAME_INVALID, gT('Credentials are valid but we failed to create a user'));
                 return;
             }
