@@ -12,12 +12,14 @@
     * See COPYRIGHT.php for copyright notices and details.
     *
     */
-  if (!isset($argv[0])) die();
-  define('BASEPATH','.');
-  $sCurrentDir=dirname(__FILE__);
-  $config=require (dirname($sCurrentDir).DIRECTORY_SEPARATOR.'config'.DIRECTORY_SEPARATOR.'config.php');
-  unset ($config['defaultController']);
-  unset ($config['config']);
-  require (dirname(dirname($sCurrentDir)).DIRECTORY_SEPARATOR.'framework'.DIRECTORY_SEPARATOR.'yiic.php');
+    if (!isset($argv[0])) {
+        die();
+    }
+    define('BASEPATH', '.');
+    $sCurrentDir = dirname(__FILE__);
+    $config = require (dirname($sCurrentDir).DIRECTORY_SEPARATOR.'config'.DIRECTORY_SEPARATOR.'config.php');
+    unset ($config['defaultController']);
+    unset ($config['config']);
+    require (dirname(dirname($sCurrentDir)).DIRECTORY_SEPARATOR.'framework'.DIRECTORY_SEPARATOR.'yiic.php');
 
 ?>
\ No newline at end of file
